@@ -7,7 +7,8 @@ from types import MethodType
 from boto3.docs.utils import is_resource_action
 from boto3.resources.base import ServiceResource as Boto3ServiceResource
 
-from mypy_boto3_builder.parsers.helpers import parse_attributes, parse_method
+from mypy_boto3_builder.parsers.helpers import parse_method
+from mypy_boto3_builder.parsers.parse_attributes import parse_attributes
 from mypy_boto3_builder.parsers.parse_collections import parse_collections
 from mypy_boto3_builder.parsers.parse_identifiers import parse_identifiers
 from mypy_boto3_builder.parsers.parse_references import parse_references
@@ -47,20 +48,17 @@ def parse_resource(
             method = parse_method(name, method_name, public_method, service_name)
 
         docstring = get_short_docstring(inspect.getdoc(public_method) or "")
-        method.docstring = "".join(
-            (
-                f"{docstring}\n\n" if docstring else "",
-                "[Show boto3 documentation]",
-                f"({service_name.get_boto3_doc_link(name, method_name)})\n",
-                "[Show boto3-stubs documentation]",
-                f"({service_name.get_doc_link('service_resource', name, f'{method_name} method')})",
-            )
-        )
+        method.docstring = docstring
         result.methods.append(method)
 
-    result.attributes.extend(parse_attributes(service_name, name, resource))
-    result.attributes.extend(parse_identifiers(resource))
-    result.attributes.extend(parse_references(resource))
+    attributes = parse_attributes(service_name, name, resource, shape_parser)
+    result.attributes.extend(attributes)
+
+    identifiers = parse_identifiers(resource)
+    result.attributes.extend(identifiers)
+
+    references = parse_references(resource)
+    result.attributes.extend(references)
 
     collections = parse_collections(name, resource, service_name, shape_parser)
     for collection in collections:
