@@ -117,6 +117,10 @@ class AioBotocorePostprocessor(BasePostprocessor):
             for collection in sub_resource.collections:
                 for method in collection.methods:
                     method.is_async = True
+            for attribute in sub_resource.attributes:
+                attribute.type_annotation = TypeSubscript(
+                    Type.Awaitable, [attribute.type_annotation]
+                )
 
     def _add_contextmanager_methods(self) -> None:
         self.package.client.methods.append(
